gloo/migrate

Migration CLI entry point. Call migrate.main_with_migrations(repo, migrations) from your main function to expose the migrate subcommand.

Subcommands: up [--step N], down [--step N], status, gen <name>.

Values

pub fn main_with_migrations(
  r: repo.Repo,
  migrations: List(migration.Migration),
) -> Nil

Entry point for the migration CLI. Call this from your app’s main function, passing the Repo and your migration list.

Usage: gleam run -m myapp/db – migrate up gleam run -m myapp/db – migrate up –step 2 gleam run -m myapp/db – migrate down –step 1 gleam run -m myapp/db – migrate status gleam run -m myapp/db – migrate gen create_posts

Search Document